Box class

Implementers
Available extensions

Constructors

Box({String? name, Color? color, EdgeInsets? padding, BoxDecoration? decoration, Border? border, BorderRadius? borderRadius, Color? borderColor, double? height, double? width, double? textSize, Color? textColor, FontWeight? textWeight, TextStyle textStyle = const TextStyle()})
Box.from(Box box)
factory

Properties

border → Border?
final
borderColor → Color?
final
borderRadius → BorderRadius?
final
color → Color?
final
decoration → BoxDecoration?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
name → String?
final
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color?
final
textSize → double?
final
textStyle ↔ TextStyle
getter/setter pair
textWeight → FontWeight?
final
width → double?
final

Methods

copyWith({Color? color, double? height, double? width, EdgeInsets? padding, Border? border, BorderRadius? borderRadius, Color? borderColor, BoxDecoration? decoration, Color? textColor, FontWeight? textWeight, double? textSize, TextStyle? textStyle}) → Box

Available on Box, provided by the Utils extension

getDecoration() → BoxDecoration

Available on Box, provided by the Utils extension

getTextStyle() → TextStyle

Available on Box, provided by the Utils extension

merge(Iterable<Box?> boxes) → Box

Available on Box, provided by the Utils extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited