BoxState class mixin

Implementers

Constructors

BoxState()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variants → Map<String, Box?>
no setter

Methods

getVariant(String name) → Box?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVariants(Map<String, Box?> value) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited