BoxStyle class

Inheritance
Mixed-in types
Available extensions

Constructors

BoxStyle({Box? hoverStyle, Box? activeStyle, Box? errorStyle, Box? disabledStyle, String? name, Color? color, BoxDecoration? decoration, EdgeInsets? padding, Border? border, BorderRadius? borderRadius, Color? borderColor, Color? textColor, FontWeight? textWeight, double? textSize, TextStyle textStyle = const TextStyle(), double? height, double? width})
BoxStyle.from(BoxStyle style)
factory
BoxStyle.fromBox(Box style, {Box? hoverStyle, Box? activeStyle, Box? errorStyle, Box? disabledStyle})
factory

Properties

activeStyle → Box
no setter
border → Border?
finalinherited
borderColor → Color?
finalinherited
borderRadius → BorderRadius?
finalinherited
color → Color?
finalinherited
decoration → BoxDecoration?
finalinherited
disabledStyle → Box
no setter
errorStyle → Box
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double?
finalinherited
hoverStyle → Box
no setter
name → String?
finalinherited
padding → EdgeInsets?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color?
finalinherited
textSize → double?
finalinherited
textStyle ↔ TextStyle
getter/setter pairinherited
textWeight → FontWeight?
finalinherited
variants → Map<String, Box?>
no setterinherited
width → double?
finalinherited

Methods

copyWith({String? name, Border? border, Color? borderColor, BorderRadius? borderRadius, Color? color, BoxDecoration? decoration, double? height, EdgeInsets? padding, Color? textColor, double? textSize, TextStyle? textStyle, FontWeight? textWeight, double? width, Box? activeStyle, Box? disabledStyle, Box? errorStyle, Box? hoverStyle}) → BoxStyle
copyWith({Color? color, double? height, double? width, EdgeInsets? padding, Border? border, BorderRadius? borderRadius, Color? borderColor, BoxDecoration? decoration, Color? textColor, FontWeight? textWeight, double? textSize, TextStyle? textStyle}) → Box

Available on Box, provided by the Utils extension

getDecoration() → BoxDecoration

Available on Box, provided by the Utils extension

getTextStyle() → TextStyle

Available on Box, provided by the Utils extension

getVariant(String name) → Box?
inherited
merge(List<BoxStyle?> boxes) → BoxStyle
merge(Iterable<Box?> boxes) → Box

Available on Box, provided by the Utils extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVariants(Map<String, Box?> value) → void
inherited
toBox({String? name}) → Box
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited