BaseTextSize class

Constructors

BaseTextSize(double size)

Properties

hashCode → int
The hash code for this object.
no setterinherited
none → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
final
sm → double
no setter
x1 → double
no setter
x2 → double
no setter
x3 → double
no setter
x4 → double
no setter
xf1 → double
no setter
xf2 → double
no setter
xf3 → double
no setter
xs → double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
times(double value) → double
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited